@@ -21,12 +21,7 @@
 #include <QVBoxLayout>
 
 #include <KIO/OpenUrlJob>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KGuiItem>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
@@ -140,7 +135,7 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
     const PlayerInfos &p = internal->playerInfos();
 
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setSpacing(QApplication::fontMetrics().lineSpacing());
+    vbox->setSpacing(fontMetrics().lineSpacing());
 
     _tw = new QTabWidget(this);
     connect(_tw, &QTabWidget::currentChanged, this, &HighscoresWidget::handleTabChanged);
@@ -173,15 +168,13 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
         QUrl url = internal->queryUrl(ManagerPrivate::Scores);
         _scoresUrl = new KUrlLabel(url.url(),
                                    i18n("View world-wide highscores"), this);
-        connect(_scoresUrl, qOverload<>(&KUrlLabel::leftClickedUrl), this,
-                &HighscoresWidget::handleUrlClicked);
+        connect(_scoresUrl, &KUrlLabel::leftClickedUrl, this, &HighscoresWidget::handleUrlClicked);
         vbox->addWidget(_scoresUrl);
 
         url = internal->queryUrl(ManagerPrivate::Players);
         _playersUrl = new KUrlLabel(url.url(),
                                     i18n("View world-wide players"), this);
-        connect(_playersUrl, qOverload<>(&KUrlLabel::leftClickedUrl), this,
-                &HighscoresWidget::handleUrlClicked);
+        connect(_playersUrl, &KUrlLabel::leftClickedUrl, this, &HighscoresWidget::handleUrlClicked);
         vbox->addWidget(_playersUrl);
     }
     load(-1);
@@ -202,11 +195,7 @@ void HighscoresWidget::handleUrlClicked()
     }
 //   kDebug(11001) ;
     auto *job = new KIO::OpenUrlJob(QUrl(label->url()));
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#endif
     job->start();
 }
 
@@ -288,7 +277,7 @@ void HighscoresDialog::slotUser2()
 //   kDebug(11001) ;
     QUrl url = QFileDialog::getSaveFileUrl(this, tr("HighscoresDialog"), QUrl(), QString());
     if ( url.isEmpty() ) return;
-    auto job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+    auto job = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
     KJobWidgets::setWindow(job, this);
     job->exec();
     if (!job->error()) {
@@ -311,7 +300,7 @@ void HighscoresDialog::slotUser2()
 
 //-----------------------------------------------------------------------------
 LastMultipleScoresList::LastMultipleScoresList(
-                            const QVector<Score> &scores, QWidget *parent)
+                            const QList<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
 //     kDebug(11001) << ": LastMultipleScoresList";
@@ -355,7 +344,7 @@ QString LastMultipleScoresList::itemText(const ItemContainer &item,
 
 //-----------------------------------------------------------------------------
 TotalMultipleScoresList::TotalMultipleScoresList(
-                            const QVector<Score> &scores, QWidget *parent)
+                            const QList<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
 //     kDebug(11001) << ": TotalMultipleScoresList";
