@@ -39,7 +39,7 @@ KReversiMainWindow::KReversiMainWindow(QWidget* parent, bool startDemo)
     memset(m_player, 0, sizeof(m_player));
 
     m_provider = new KGameThemeProvider();
-    m_provider->discoverThemes(QStringLiteral("pics"));
+    m_provider->discoverThemes(QStringLiteral("themes"));
 
     for (auto &label : m_statusBarLabel) {
        label = new QLabel(this);
